/****************************************************************************/
/*                   Copyright(C) 2001 FabIATech Corporation                */
/* FileName : DEMO.C                                                        */
/* Function : Watch Dog of F81216D Program (for FINTEK F81216D)             */
/* Design's : By Jimmy Chang                                                */
/* BuildDate: 26/04/2006 V1.1                                               */
/****************************************************************************/

/*Include file as follows:             */
#include <stdio.h>
#include <dos.h>
#include <dir.h>
#include <DEMO.h>

/*Default value define as follows:     */
#define equIndexPort 0x4e  /*super IO of index port for Super I/O               */
#define equDataPort 0x4f   /*super IO of data port for Super I/O                */
#define equDeviceCR 0x07   /*select super IO device of index port for Super I/O */
#define WDTCS 0x300        /*set Watch Dog timer configuration status           */
#define WDTtimer 0x301     /*set WDT Timer and Enable                           */

/*Declaration function as follows:     */
void OpenIoConfig(void);                  /*open super IO of configuration register for Super I/O */
void CloseIoConfig(void);                 /*close super IO of configuration register for Super I/O */
void SelectIoDevice(char cSelectDEV);     /*select super IO of device for Super I/O   */
void WriteIoCR(char cIndex, char cData);  /*write super IO of configuration register for Supe I/O  */
void InitWD(void);                        /*initial watch dog  */
void WDT_Set(char WdUnit ,char cWdTime);  /*Set watch dog timer   */
void EnWD(char cSetWatchDogUnit, char cWatchDogValue);  /*Enable watch dog  */
void DisWD(void);                         /*Disable watch dog  */
void Logo(void);                          /*Show  FabIATech Corp and Program Version:1.1  */

void main()
{ /*main_s */
char cWdTime=0x3;    /*Set Watch Dog Timer Output is 3 Second */
char cInKey;

InitWD();            /*Set First Configuration status  */

for(;;)
   {/* for_s1  */
   clrscr();
   Logo();
   printf("Press <Y> or <y> run Watch Dog. \n");
   printf("Press <Q> or <q> quit program and disable watch dog. \n");
   printf("Please Input Key Value ==> ");
   cInKey=getche();
   switch(cInKey)
     {/* switch_s1  */
     case 'Y':
     case 'y':
	     printf("\n\nPlease waiting 3 second.\n");
	     EnWD(equWdUnitS,cWdTime);  /* Enable Watch Dog Timer  */
	     exit(1);
     case 'Q':
     case 'q':
	     printf("\n\nDisabled Watch Dog and Quit Programming.\n");
	     DisWD();        /* Disable Watch Dog Timer */
	     return;
     }/* switch_e1 */
   delay(500);
   }/* for_e1 */
} /*main_e */

/*==========================================================================*/
/* OpenIoConfig                                                             */
/*==========================================================================*/
/* Function : open super IO of configuration register for Super I/O         */
/* Enter    : None                                                          */
/* Return   : None                                                          */
/*==========================================================================*/
void OpenIoConfig(void)
{
/*super IO of index port for Super I/O */
outportb(equIndexPort,0x87);
outportb(equIndexPort,0x87);       /*Entry configuration mode  */
}	

/*==========================================================================*/
/* CloseIoConfig                                                            */
/*==========================================================================*/
/* Function : close super IO of configuration register for Super I/O        */
/* Enter    : None                                                          */
/* Return   : None                                                          */
/*==========================================================================*/
void CloseIoConfig(void)
{
/*Exit configuration mode */
outportb(equIndexPort,0xaa);  
}

/*==========================================================================*/
/* SelectIoDevice                                                           */
/*==========================================================================*/
/* Function : select super IO of device for Super I/O                       */
/* Enter    : cSelectDEV = select device of function                        */
/* Return   : None                                                          */
/*==========================================================================*/
void SelectIoDevice(char cSelectDEV)
{
/*super IO of index port for Super I/O  */
/*select super IO device of index port for Super I/O  */
outportb(equIndexPort,equDeviceCR);

/*super IO of data for Super I/O   */
/*select device of function        */
outportb(equDataPort,cSelectDEV);
}

/*==========================================================================*/
/* WriteIoCR                                                                */
/*==========================================================================*/
/* Function : write super IO of configuration register for Supe I/O         */
/* Enter    : cIndex = select index port of configuration register(CR)      */
/*            cData  = configuration register of data                       */
/* Return   : None                                                          */
/*==========================================================================*/
void WriteIoCR(char cIndex, char cData)
{
/*super IO of index port for Super I/O            */
/*select super IO of index register for Super I/O */
outportb(equIndexPort,cIndex);

/*super IO of data for Super I/O                  */
/*write data to data register                     */
outportb(equDataPort,cData);
}

/*==========================================================================*/
/* InitWD                                                                   */
/*==========================================================================*/
/* Function : initial watch dog                                             */
/* Enter    : None          						                        */
/* Return   : None                                                          */
/*==========================================================================*/
void InitWD(void)
{
OpenIoConfig();		               /*open super IO of configuration for Super I/O         */
outportb(equIndexPort,0x07);       /*Select Device register Index                         */
outportb(equDataPort,0x08);        /*select LDN 8 (Watch Dog Timer Device control regist) */
outportb(equIndexPort,0x60);       /*select LDN 8 register index 0x60                     */
outportb(equDataPort,0x03);        /*Set Watch Dog timer base address high byte to 0x03   */
outportb(equIndexPort,0x61);       /*select LDN 8 register index 0x61                     */
outportb(equDataPort,0x00);        /*Set Watch Dog timer base address Low byte to 0x00    */ 
SelectIoDevice(0x08);              /*select device8                                       */
WriteIoCR(0x30,0x01);              /*select LDN 8 register index 0x30,Enable Watch Dog Timer Device */
CloseIoConfig();	               /*close super IO of configuration for Super I/O        */

}

/*==========================================================================*/
/* EnWD                                                                     */
/*==========================================================================*/
/* Function : Enable watch dog                                              */
/* Enter    : cSetWatchDogUnit = Set second or minute                       */
/*            cWatchDogValue = watch dog time out of value                  */
/*               05h : minute                                               */
/*               03h : second                                               */
/* Return   : None                                                          */
/*==========================================================================*/
void EnWD(char cSetWatchDogUnit, char cWatchDogValue)
{
outportb(WDTCS,cSetWatchDogUnit);   /*Select unit to one second and clear time out status */
outportb(WDTtimer,cWatchDogValue);
outportb(WDTtimer,cWatchDogValue);  /*Set timer to user define second and enable timer */
}

/*==========================================================================*/
/* DisWD                                                                    */
/*==========================================================================*/
/* Function : Disable watch dog                                             */
/* Enter    : None              					                        */
/* Return   : None                                                          */
/*==========================================================================*/
void DisWD(void) 
{
outportb(WDTtimer,0x00);	/*Write 0 to Disable Timer */
}

/*==========================================================================*/
/* Logo                                                                     */
/*==========================================================================*/
/* Function : Show  FabIATech Corp and Program Version:1.1                  */
/* Enter    : None              					                        */
/* Return   : None                                                          */
/*==========================================================================*/
void Logo(void)
{
printf("    =======================================================================\n");
printf("    ||Watch Dog Timer of Program from FabIATech Corp                     ||\n");
printf("    ||This program is design for test Watch Dog Timer for FINTEK F81216D.||\n");
printf("    ||Program Version:1.1 Copyright(C) 04/25/2006 by Jimmy Chang.        ||\n");
printf("    =======================================================================\n");
}